def dashboard_row_disk_space(panel_id, node):
    queries_bytes = []
    queries_inodes = []

    for measurement in [
        'used',
        'free',
    ]:
        queries_bytes.append({
            'groupBy': [
                {'type': 'time', 'params': ['$__interval']},
                {'type': 'fill', 'params': ['linear']},
            ],
            'orderByTime': "ASC",
            'policy': "default",
            'query': f"""from(bucket: "telegraf")
    |> range(start: v.timeRangeStart, stop: v.timeRangeStop)
    |> filter(fn: (r) =>
        r["_measurement"] == "disk" and
        r["_field"] == "{measurement}" and
        r["fstype"] == "ext4" and
        r["host"] == "{node.name}"
    )
    |> aggregateWindow(every: v.windowPeriod, fn: mean, createEmpty: false)
    |> yield(name: "{measurement}")""",
            'resultFormat': 'time_series',
            'select': [[
                {'type': 'field', 'params': ['value']},
                {'type': 'mean', 'params': []},
            ]],
            "tags": []
        })

    for measurement in [
        'inodes_used',
        'inodes_free',
    ]:
        queries_inodes.append({
            'groupBy': [
                {'type': 'time', 'params': ['$__interval']},
                {'type': 'fill', 'params': ['linear']},
            ],
            'orderByTime': "ASC",
            'policy': "default",
            'query': f"""from(bucket: "telegraf")
    |> range(start: v.timeRangeStart, stop: v.timeRangeStop)
    |> filter(fn: (r) =>
        r["_measurement"] == "disk" and
        r["_field"] == "{measurement}" and
        r["fstype"] == "ext4" and
        r["host"] == "{node.name}"
    )
    |> aggregateWindow(every: v.windowPeriod, fn: mean, createEmpty: false)
    |> yield(name: "{measurement}")""",
            'resultFormat': 'time_series',
            'select': [[
                {'type': 'field', 'params': ['value']},
                {'type': 'mean', 'params': []},
            ]],
            "tags": []
        })

    return {
        'title': 'disk space',
        'collapse': False,
        'editable': False,
        'height': '200px',
        'panels': [
            {
                'aliasColors': {},
                'bars': False,
                'dashLength': 10,
                'dashes': False,
                'datasource': None,
                'fieldConfig': {
                    'defaults': {
                        'displayName': '${__field.name} ${__field.labels.path}'
                    },
                    'overrides': []
                },
                'fill': 1,
                'fillGradient': 0,
                'hiddenSeries': False,
                'id': next(panel_id),
                'legend': {
                    'alignAsTable': False,
                    'avg': False,
                    'current': False,
                    'max': False,
                    'min': False,
                    'rightSide': False,
                    'show': True,
                    'total': False,
                    'values': False
                },
                'lines': True,
                'linewidth': 1,
                'NonePointMode': 'None',
                'options': {
                    'alertThreshold': True
                },
                'percentage': False,
                'pluginVersion': '7.5.5',
                'pointradius': 2,
                'points': False,
                'renderer': 'flot',
                'seriesOverrides': [],
                'spaceLength': 10,
                'span': 6,
                'stack': True,
                'steppedLine': False,
                'targets': queries_bytes,
                'thresholds': [],
                'timeRegions': [],
                'title': 'disk space',
                'tooltip': {
                    'shared': True,
                    'sort': 0,
                    'value_type': 'individual'
                },
                'type': 'graph',
                'xaxis': {
                    'buckets': None,
                    'mode': 'time',
                    'name': None,
                    'show': True,
                    'values': []
                },
                'yaxes': [
                    {
                        'format': 'bytes',
                        'label': None,
                        'logBase': 1,
                        'max': None,
                        'min': 0,
                        'show': True,
                    },
                    {
                        'format': 'short',
                        'label': None,
                        'logBase': 1,
                        'max': None,
                        'min': None,
                        'show': False,
                    }
                ],
                'yaxis': {
                    'align': False,
                    'alignLevel': None
                }
            },
            {
                'aliasColors': {},
                'bars': False,
                'dashLength': 10,
                'dashes': False,
                'datasource': None,
                'fieldConfig': {
                    'defaults': {
                        'displayName': '${__field.name} ${__field.labels.path}'
                    },
                    'overrides': []
                },
                'fill': 1,
                'fillGradient': 0,
                'hiddenSeries': False,
                'id': next(panel_id),
                'legend': {
                    'alignAsTable': False,
                    'avg': False,
                    'current': False,
                    'max': False,
                    'min': False,
                    'rightSide': False,
                    'show': True,
                    'total': False,
                    'values': False
                },
                'lines': True,
                'linewidth': 1,
                'NonePointMode': 'None',
                'options': {
                    'alertThreshold': True
                },
                'percentage': False,
                'pluginVersion': '7.5.5',
                'pointradius': 2,
                'points': False,
                'renderer': 'flot',
                'seriesOverrides': [],
                'spaceLength': 10,
                'span': 6,
                'stack': True,
                'steppedLine': False,
                'targets': queries_inodes,
                'thresholds': [],
                'timeRegions': [],
                'title': 'disk inodes',
                'tooltip': {
                    'shared': True,
                    'sort': 0,
                    'value_type': 'individual'
                },
                'type': 'graph',
                'xaxis': {
                    'buckets': None,
                    'mode': 'time',
                    'name': None,
                    'show': True,
                    'values': []
                },
                'yaxes': [
                    {
                        'format': 'bytes',
                        'label': None,
                        'logBase': 1,
                        'max': None,
                        'min': 0,
                        'show': True,
                    },
                    {
                        'format': 'short',
                        'label': None,
                        'logBase': 1,
                        'max': None,
                        'min': None,
                        'show': False,
                    }
                ],
                'yaxis': {
                    'align': False,
                    'alignLevel': None
                }
            },
        ],
    }
